#
# spec file for package python-furl
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python3-furl
Version:        2.1.0
Release:        bp156.1.1
Summary:        A Python URL manipulation library
License:        Unlicense
Group:          Development/Languages/Python
URL:            https://github.com/gruns/furl
Source:         https://files.pythonhosted.org/packages/source/f/furl/furl-%{version}.tar.gz
# PATCH-FIX-UPSTREAM tests_overcome_bpo42967.patch gh#gruns/furl#135 mcepl@suse.com
# With fix for bpo#42967, it is not possible to separate
# parameters of URL query with semicolon
Patch0:         tests_overcome_bpo42967.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python3-orderedmultidict >= 1.0
Requires:       python3-six >= 1.8.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module orderedmultidict >= 1.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six >= 1.8.0}
# /SECTION
%python_subpackages

%description
furl is a Python library for parsing and manipulating URLs.

%prep
%autosetup -p1 -n furl-%{version}

chmod -x *.md

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -vv

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/*

%changelog
* Tue Feb 23 2021 Matej Cepl <mcepl@suse.com>
- Switch testing to pytest, it is just more convenient to debug.
- Add tests_overcome_bpo42967.patch to overcome changes in Python
  interpreter after fixing bpo#42967 (gh#gruns/furl#135).
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 2.1.0
    Added: a dont_quote= parameter to Query.encode() and a
    query_dont_quote= parameter to furl.tostr() that exempt valid query
    characters from being percent-encoded, either in their entirety with
    dont_quote=True, or selectively with dont_quote=<string>, like
    dont_quote='/?@_'.
    Changed: Move package info from __init__.py into the more standard
    __version__.py.
    Fixed: Support Unicode usernames and passwords in Python 2.
    Fixed: Update orderedmultdict to v1.0.1 to resolve a DeprecationWarning.
    Fixed: Encode '/' consistently in query strings across both
    quote_plus=True and quote_plus=False.
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Sun Jun  2 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.0
